@@ -21,7 +21,8 @@ multiscale = list(
 print('multiscale level shapes: ', [p.shape[:2] for p in multiscale])
 
 # add image multiscale
-viewer = napari.view_image(multiscale, multiscale=True)
+viewer = napari.Viewer()
+layer = viewer.add_image(multiscale, multiscale=True)
 
 if __name__ == '__main__':
     napari.run()
