@@ -2,7 +2,7 @@
 nD image
 ========
 
-Display one 4-D image layer using the :func:`view_image` API.
+Display one 4-D image layer using the :func:`add_image` API.
 
 .. tags:: visualization-nD
 """
@@ -21,7 +21,8 @@ blobs = np.stack(
     ],
     axis=0,
 )
-viewer = napari.view_image(blobs.astype(float))
+viewer = napari.Viewer()
+layer = viewer.add_image(blobs.astype(float))
 
 if __name__ == '__main__':
     napari.run()
