@@ -22,7 +22,8 @@ multiscale = list(
 print('multiscale level shapes: ', [p.shape for p in multiscale])
 
 # add image multiscale
-viewer = napari.view_image(multiscale, contrast_limits=[0, 1], multiscale=True)
+viewer = napari.Viewer()
+layer = viewer.add_image(multiscale, contrast_limits=[0, 1], multiscale=True)
 
 if __name__ == '__main__':
     napari.run()
