@@ -13,7 +13,8 @@ import napari
 from napari.utils.theme import available_themes, get_theme, register_theme
 
 # create the viewer with an image
-viewer = napari.view_image(data.astronaut(), rgb=True, name='astronaut')
+viewer = napari.Viewer()
+layer = viewer.add_image(data.astronaut(), rgb=True, name='astronaut')
 
 # List themes
 print('Originally themes', available_themes())
