@@ -23,7 +23,8 @@ blobs = np.stack(
     ],
     axis=0,
 )
-viewer = napari.view_image(blobs.astype(float), rendering='attenuated_mip')
+viewer = napari.Viewer()
+layer = viewer.add_image(blobs.astype(float), rendering='attenuated_mip')
 labels = viewer.add_labels(np.zeros_like(blobs, dtype=np.int32))
 labels.n_edit_dimensions = 3
 labels.brush_size = 15
