@@ -23,7 +23,8 @@ data[53_0:53_1, 100:110, 110:120] = 1
 print(data.shape)
 # For big data, we should specify the contrast_limits range, or napari will try
 # to find the min and max of the full image.
-viewer = napari.view_image(data, contrast_limits=[0, 1], rgb=False)
+viewer = napari.Viewer()
+layer = viewer.add_image(data, contrast_limits=[0, 1], rgb=False)
 
 if __name__ == '__main__':
     napari.run()
