@@ -66,6 +66,10 @@ def _n_selected_imgs(s: LayerSel) -> int:
     return sum(x._type_string == 'image' for x in s)
 
 
+def _only_image(s: LayerSel) -> bool:
+    return bool(s and all(x._type_string == 'image' for x in s))
+
+
 def _only_labels(s: LayerSel) -> bool:
     return bool(s and all(x._type_string == 'labels' for x in s))
 
@@ -86,6 +90,10 @@ def _only_shapes(s: LayerSel) -> bool:
     return bool(s and all(x._type_string == 'shapes' for x in s))
 
 
+def _only_surfaces(s: LayerSel) -> bool:
+    return bool(s and all(x._type_string == 'surface' for x in s))
+
+
 def _n_selected_shapes(s: LayerSel) -> int:
     return sum(x._type_string == 'shapes' for x in s)
 
@@ -184,6 +192,10 @@ def _active_supports_features(s: LayerSel) -> bool:
     return hasattr(s.active, 'features')
 
 
+def _all_support_colorbar(s: LayerSel) -> bool:
+    return bool(s and all(hasattr(x, 'colorbar') for x in s))
+
+
 class LayerListSelectionContextKeys(ContextNamespace['LayerSel']):
     """Available context keys relating to the selection in a LayerList.
 
@@ -288,6 +300,11 @@ class LayerListSelectionContextKeys(ContextNamespace['LayerSel']):
         trans._('True when all selected layers are of the same type.'),
         _same_type,
     )
+    all_selected_layers_image = ContextKey(
+        False,
+        trans._('True when all selected layers are images.'),
+        _only_image,
+    )
     all_selected_layers_labels = ContextKey(
         False,
         trans._('True when all selected layers are labels.'),
@@ -298,6 +315,16 @@ class LayerListSelectionContextKeys(ContextNamespace['LayerSel']):
         trans._('True when all selected layers are shapes.'),
         _only_shapes,
     )
+    all_selected_layers_surfaces = ContextKey(
+        False,
+        trans._('True when all selected layers are surfaces.'),
+        _only_surfaces,
+    )
+    all_selected_layers_support_colorbar = ContextKey(
+        False,
+        trans._('True when all selected layers support a colorbar.'),
+        _all_support_colorbar,
+    )
     selected_empty_shapes_layer = ContextKey(
         False,
         trans._('True when there is a shapes layer without data selected.'),
