@@ -10,7 +10,7 @@ def test_out_of_slice_display_checkbox(qtbot):
     layer = Vectors(_VECTORS)
     qtctrl = QtVectorsControls(layer)
     qtbot.addWidget(qtctrl)
-    qtctrl.outOfSliceCheckBox.setChecked(True)
+    qtctrl._out_slice_checkbox_control.out_of_slice_checkbox.setChecked(True)
     assert layer.out_of_slice_display
-    qtctrl.outOfSliceCheckBox.setChecked(False)
+    qtctrl._out_slice_checkbox_control.out_of_slice_checkbox.setChecked(False)
     assert not layer.out_of_slice_display
