@@ -91,7 +91,7 @@ def test_cli_runscript(monkeypatch, tmp_path, make_napari_viewer):
         m.setattr(sys, 'argv', ['napari', str(script)])
         m.setattr(__main__, 'Viewer', lambda: v)
         m.setattr(
-            'qtpy.QtWidgets.QApplication.exec_', lambda: None
+            'qtpy.QtWidgets.QApplication.exec_', lambda *_: None
         )  # revent event loop if run this test standalone
         __main__._run()
 
