@@ -1,6 +1,8 @@
 from functools import partial
+from pathlib import Path
 from typing import Dict, List, Optional, TYPE_CHECKING, Tuple
 from packaging.version import parse as parse_version
+import os
 
 from qtpy import QtCore, QtGui, QtWidgets, QT_VERSION
 
@@ -369,8 +371,22 @@ class FilepathSchemaWidget(SchemaWidgetMixin, QtWidgets.QWidget):
         self.button_widget.clicked.connect(self._on_clicked)
         self.path_widget.textChanged.connect(self.on_changed.emit)
 
+
+    def file_filter(self) -> str:
+        if "json_schema_extra" in self.schema and 'file_extension' in self.schema['json_schema_extra']:
+            extension = self.schema['json_schema_extra']['file_extension']
+            return f"File (*.{extension})"
+        return "All Files (*)"
+
     def _on_clicked(self, flag):
-        path, filter = QtWidgets.QFileDialog.getOpenFileName()
+        if self.path_widget.text():
+            start_dir = os.path.dirname(self.path_widget.text())
+        else:
+            start_dir = os.path.expanduser("~")
+
+        path, filter = QtWidgets.QFileDialog.getOpenFileName(self, "Select File", start_dir, self.file_filter())
+        if not path:
+            return
         self.path_widget.setText(path)
 
     @state_property
@@ -378,7 +394,9 @@ class FilepathSchemaWidget(SchemaWidgetMixin, QtWidgets.QWidget):
         return self.path_widget.text()
 
     @state.setter
-    def state(self, state: str):
+    def state(self, state: str | Path):
+        if isinstance(state, Path):
+            state = str(state)
         self.path_widget.setText(state)
 
     def setDescription(self, description: str):
