@@ -17,6 +17,7 @@ from napari._vispy.overlays.axes import VispyAxesOverlay
 from napari._vispy.overlays.base import VispyBaseOverlay
 from napari._vispy.overlays.bounding_box import VispyBoundingBoxOverlay
 from napari._vispy.overlays.brush_circle import VispyBrushCircleOverlay
+from napari._vispy.overlays.colorbar import VispyColorBarOverlay
 from napari._vispy.overlays.interaction_box import (
     VispySelectionBoxOverlay,
     VispyTransformBoxOverlay,
@@ -29,6 +30,7 @@ from napari.components.overlays import (
     AxesOverlay,
     BoundingBoxOverlay,
     BrushCircleOverlay,
+    ColorBarOverlay,
     LabelsPolygonOverlay,
     Overlay,
     ScaleBarOverlay,
@@ -70,6 +72,7 @@ overlay_to_visual: dict[type[Overlay], type[VispyBaseOverlay]] = {
     BrushCircleOverlay: VispyBrushCircleOverlay,
     LabelsPolygonOverlay: VispyLabelsPolygonOverlay,
     ZoomOverlay: VispyZoomOverlay,
+    ColorBarOverlay: VispyColorBarOverlay,
 }
 
 
