@@ -6,6 +6,7 @@ from napari.components.overlays.base import (
 )
 from napari.components.overlays.bounding_box import BoundingBoxOverlay
 from napari.components.overlays.brush_circle import BrushCircleOverlay
+from napari.components.overlays.colorbar import ColorBarOverlay
 from napari.components.overlays.interaction_box import (
     SelectionBoxOverlay,
     TransformBoxOverlay,
@@ -20,6 +21,7 @@ __all__ = [
     'BoundingBoxOverlay',
     'BrushCircleOverlay',
     'CanvasOverlay',
+    'ColorBarOverlay',
     'LabelsPolygonOverlay',
     'Overlay',
     'ScaleBarOverlay',
