@@ -434,8 +434,30 @@ def test_adding_points_to_empty():
     assert layer.selected_data == {0}
 
 
+def test_removing_points():
+    """Test removing points, including with selection."""
+    shape = (10, 2)
+    np.random.seed(0)
+    data = 20 * np.random.random(shape)
+    layer = Points(data)
+    # select some points
+    layer.selected_data = {1, 2, 4, 6}
+
+    # Remove points by index
+    layer.remove([0, 2, 5])
+    assert len(layer.data) == shape[0] - 3
+    assert np.array_equal(layer.data, data[[1, 3, 4, 6, 7, 8, 9]])
+
+    # check selection after removal
+    # one selected point was removed, the other indexes need to be shifted
+    assert layer.selected_data == {0, 2, 3}
+
+    # removing nothing should work smoothly
+    layer.remove([])
+
+
 def test_removing_selected_points():
-    """Test selecting points."""
+    """Test removing selected points."""
     shape = (10, 2)
     np.random.seed(0)
     data = 20 * np.random.random(shape)
@@ -460,6 +482,26 @@ def test_removing_selected_points():
     assert len(layer.data) == shape[0] - 3
 
 
+def test_popping_points():
+    """Test popping points."""
+    shape = (10, 2)
+    np.random.seed(0)
+    data = 20 * np.random.random(shape)
+    layer = Points(data)
+
+    # Pop point by default index
+    popped = layer.pop()
+    assert len(layer.data) == shape[0] - 1
+    assert np.array_equal(popped['data'], data[-1])
+    assert np.array_equal(layer.data, data[:-1])
+
+    # Pop a point by index at 3
+    popped = layer.pop(3)
+    assert len(layer.data) == shape[0] - 2
+    assert np.array_equal(popped['data'], data[3])
+    assert np.array_equal(layer.data, data[[0, 1, 2, 4, 5, 6, 7, 8]])
+
+
 def test_deleting_selected_value_changes():
     """Test deleting selected points appropriately sets self._value"""
     shape = (10, 2)
@@ -1002,7 +1044,7 @@ def test_points_errors():
 
     # try adding properties with the wrong number of properties
     with pytest.raises(
-        ValueError, match='(does not match length)|(indices imply)'
+        ValueError, match=r'does not match length|indices imply'
     ):
         Points(data, properties=copy(annotations))
 
@@ -1182,7 +1224,7 @@ def test_colormap_without_properties(attribute):
     data = 20 * np.random.random(shape)
     layer = Points(data)
 
-    with pytest.raises(ValueError, match='must be a valid Points.properties'):
+    with pytest.raises(ValueError, match=r'must be a valid Points.properties'):
         setattr(layer, f'{attribute}_color_mode', 'colormap')
 
 
@@ -1198,7 +1240,7 @@ def test_colormap_with_categorical_properties(attribute):
     with (
         pytest.raises(
             TypeError,
-            match='selected property must be numeric to use ColorMode.COLORMAP',
+            match=r'selected property must be numeric to use ColorMode.COLORMAP',
         ),
         pytest.warns(
             UserWarning,
@@ -2346,12 +2388,16 @@ def test_set_properties_with_invalid_shape_errors_safely():
     properties = {
         'class': np.array(['A', 'B', 'C']),
     }
-    points = Points(np.random.rand(3, 2), text='class', properties=properties)
+    points = Points(
+        np.random.default_rng(0).random((3, 2)),
+        text='class',
+        properties=properties,
+    )
     np.testing.assert_equal(points.properties, properties)
     np.testing.assert_array_equal(points.text.values, ['A', 'B', 'C'])
 
     with pytest.raises(
-        ValueError, match='(does not match length)|(indices imply)'
+        ValueError, match=r'does not match length|indices imply'
     ):
         points.properties = {'class': np.array(['D', 'E'])}
 
@@ -2738,3 +2784,15 @@ def test_docstring():
     validate_all_params_in_docstring(Points)
     validate_kwargs_sorted(Points)
     validate_docstring_parent_class_consistency(Points)
+
+
+def test_points_layer_display_correct_slice_on_scale(viewer_model):
+    data = np.zeros((60, 60, 60))
+    viewer_model.add_image(data, scale=[0.29, 0.26, 0.26])
+    pts = viewer_model.add_points(name='test', size=1, ndim=3)
+    pts.add((8.7, 0, 0))
+    viewer_model.dims.set_point(0, 30 * 0.29)  # middle plane
+
+    request = pts._make_slice_request(viewer_model.dims)
+    response = request()
+    np.testing.assert_equal(response.indices, [0])
