@@ -3,6 +3,7 @@ from __future__ import annotations
 import sys
 from abc import ABC, abstractmethod
 from functools import cached_property
+from typing import Literal
 
 import numpy as np
 import numpy.typing as npt
@@ -121,6 +122,8 @@ class Shape(ABC):
         Flag to use face vertices for mask generation.
     """
 
+    slice_key: np.ndarray[tuple[Literal[2], int], np.dtype[np.int64]]
+
     def __init__(
         self,
         *,
@@ -274,6 +277,36 @@ class Shape(ABC):
     def z_index(self, z_index):
         self._z_index = z_index
 
+    @property
+    def vertices_count(self) -> int:
+        """int: Number of vertices in the shape."""
+        return self._edge_vertices.shape[0] + self._face_vertices.shape[0]
+
+    @property
+    def triangles_count(self) -> int:
+        """int: Number of triangles in the shape."""
+        return self._face_triangles.shape[0] + self._edge_triangles.shape[0]
+
+    @property
+    def face_triangles_count(self) -> int:
+        """int: Number of triangles in the face of the shape."""
+        return self._face_triangles.shape[0]
+
+    @property
+    def face_vertices_count(self) -> int:
+        """int: Number of vertices in the face of the shape."""
+        return self._face_vertices.shape[0]
+
+    @property
+    def edge_triangles_count(self) -> int:
+        """int: Number of triangles in the edge of the shape."""
+        return self._edge_triangles.shape[0]
+
+    @property
+    def edge_vertices_count(self) -> int:
+        """int: Number of vertices in the edge of the shape."""
+        return self._edge_vertices.shape[0]
+
     def _set_empty_edge(self) -> None:
         self._edge_vertices = np.empty((0, self.ndisplay), dtype=np.float32)
         self._edge_offsets = np.empty((0, self.ndisplay), dtype=np.float32)
