@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import itertools
+import warnings
 from typing import TYPE_CHECKING
 
 import numpy as np
@@ -36,6 +37,19 @@ def slice_from_axis(array, *, axis, element):
     sliced : NumPy or other array
         The sliced output array, which has one less dimension than the input.
     """
+    # Check if array is a zarr array and wrap it with dask
+    # to keep lazy behavior and avoid loading into memory
+    if hasattr(array, '__module__') and array.__module__.startswith('zarr'):
+        import dask.array as da
+
+        array = da.from_zarr(array)
+        warnings.warn(
+            trans._(
+                'zarr array cannot be sliced lazily, converted to dask array.',
+                deferred=True,
+            )
+        )
+
     slices = [slice(None) for i in range(array.ndim)]
     slices[axis] = element
     return array[tuple(slices)]
@@ -124,7 +138,9 @@ def split_channels(
                     allow_none=True,
                 )
             )
-        elif key == 'affine' and isinstance(val, np.ndarray):
+        elif key in ['rotate', 'shear'] or (
+            key == 'affine' and isinstance(val, np.ndarray)
+        ):
             # affine may be Affine or np.ndarray object that is not
             # iterable, but it is not now a problem as we use it only to warning
             # if a provided object is a sequence and channel_axis is not provided
@@ -251,15 +267,22 @@ def stack_to_images(stack: Image, axis: int, **kwargs) -> list[Image]:
 
 
 def split_rgb(stack: Image, with_alpha=False) -> list[Image]:
-    """Variant of stack_to_images that splits an RGB with predefined cmap."""
+    """Split RGB image into separate channel images while preserving affine transforms."""
     if not stack.rgb:
         raise ValueError(
             trans._('Image must be RGB to use split_rgb', deferred=True)
         )
-    # representing alpha channel as gray
-    images = stack_to_images(
-        stack, -1, colormap=('red', 'green', 'blue', 'gray')
-    )
+
+    data, meta, _ = stack.as_layer_data_tuple()
+
+    meta['colormap'] = ('red', 'green', 'blue', 'gray')
+    meta['rgb'] = False
+
+    layerdata_list = split_channels(data, channel_axis=-1, **meta)
+
+    images = [
+        Image(image, **i_kwargs) for image, i_kwargs, _ in layerdata_list
+    ]
     return images if with_alpha else images[:3]
 
 
@@ -323,6 +346,7 @@ def images_to_stack(images: list[Image], axis: int = 0, **kwargs) -> Image:
                 deferred=True,
             )
         )
+
     if all(multiscale_flags):
         # Check that all multiscale images have the same number of levels
         n_scales_list = [len(image.data) for image in images]
@@ -334,13 +358,38 @@ def images_to_stack(images: list[Image], axis: int = 0, **kwargs) -> Image:
                     n_scales_list=n_scales_list,
                 )
             )
-        n_scales = n_scales_list[0]
+        arrays_to_check = [img.data[0] for img in images]
+    else:
+        arrays_to_check = [img.data for img in images]
+
+    # check if any of the data arrays are zarr arrays
+    # zarr doesn't have a stack method, so we will use dask.array.stack
+    is_zarr = any(
+        hasattr(arr, '__module__') and arr.__module__.startswith('zarr')
+        for arr in arrays_to_check
+    )
+
+    if is_zarr:
+        import dask.array as da
+
+        stacker = da.stack
+        warnings.warn(
+            trans._(
+                'zarr array cannot be stacked lazily, using dask array to stack.',
+                deferred=True,
+            )
+        )
+    else:
+        stacker = np.stack
+
+    if all(multiscale_flags):
+        n_scales = len(images[0].data)
         new_data = [
-            np.stack([image.data[level] for image in images], axis=axis)
+            stacker([image.data[level] for image in images], axis=axis)
             for level in range(n_scales)
         ]
     else:
-        new_data = np.stack([image.data for image in images], axis=axis)
+        new_data = stacker([image.data for image in images], axis=axis)
 
     # RGB images do not need extra dimensions inserted into metadata
     # They can use the meta dict from one of the source image layers
