@@ -85,19 +85,18 @@ class PandasModel(QAbstractTableModel):
         ):
             return Qt.CheckState.Checked if value else Qt.CheckState.Unchecked
 
-        if role in {Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole}:
-            # format based on dtype
+        if role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             if pd.api.types.is_float_dtype(dtype):
-                return f'{value:.6g}'
+                return float(value)
             if pd.api.types.is_integer_dtype(dtype):
-                return f'{value:d}'
+                return int(value)
             if pd.api.types.is_datetime64_any_dtype(dtype):
                 return value.strftime('%Y-%m-%d')
             if pd.api.types.is_bool_dtype(dtype):
                 if role == Qt.ItemDataRole.DisplayRole:
                     return ''  # do not show True/False text
                 if role == Qt.ItemDataRole.EditRole:
-                    return value  # needed for proper sorting
+                    return bool(value)  # needed for proper sorting
             return str(value)
 
         return None
@@ -216,6 +215,10 @@ class DelegateCategorical(QStyledItemDelegate):
             # force editor to open on first click, otherwise we need 2 clicks
             QTimer.singleShot(0, editor.showPopup)
             return editor
+        if pd.api.types.is_float_dtype(dtype):
+            editor = super().createEditor(parent, option, index)
+            editor.setDecimals(10)
+            return editor
 
         return super().createEditor(parent, option, index)
 
